# -*- coding: utf-8 -*-
from rjsmin import jsmin
from rcssmin import cssmin

baseDirStatic = "./static/loja/estrutura/v1/"

jsSources = [
    "js/jquery-1.10.1.min.js",
    "js/jquery-ui.js",
    "js/bootstrap.min.js",
    "js/css3-mediaqueries.js",
    "js/jquery.flexslider-min.js",
    "js/jquery.mask.min.js",
    "js/modernizr.custom.17475.js",
    "js/jquery.cookie.min.js",
    "js/jquery.rwdImageMaps.min.js",
    "js/main.js"
]

cssSources = [
    "css/bootstrap.css",
    "css/font-awesome.css",
    "css/font-awesome-ie7.css",
    "css/font-awesome-v4.css",
    "css/flexslider.css",
    "css/prettify.css",
    "css/es-cus.css",
    "css/style.css",
    "css/cores.css"
]


def _minifyCSS(text):
    return cssmin(text, keep_bang_comments=True)


def _minifyJS(text):
    return jsmin(text)


def saveFile(function, sourcePaths, destPath, minPath, baseDir, header=None):
    print("Gerando arquivos {} e {}".format(destPath, minPath))
    f = open(destPath, 'w')
    mf = None
    fullminText = ""
    try:
        mf = open(minPath, 'w')
        if header:
            mf.write(header)
        for srcFile in sourcePaths:
            print(srcFile)
            with open("{}{}".format(baseDir, srcFile)) as inputFile:
                srcText = inputFile.read()
                minText = function(srcText)
                if function.__name__ == "_minifyJS":
                    if not minText[-1] == ";":
                        minText += ";"
                    minText = minText.replace("\n", ";")
            f.write(srcText)
            mf.write(minText)
            fullminText += minText
    except:
        print("Ocorreu um erro ao gerar o Minify")
        return False
    finally:
        f.close()
        if mf and not mf.closed:
            mf.close()
        return True


def minifyJS(baseDir=baseDirStatic, source=jsSources):
    jsDestPath = "{}js/all.js".format(baseDir)
    jsMinPath = "{}js/all.min.js".format(baseDir)
    return saveFile(_minifyJS, source, jsDestPath, jsMinPath, baseDir)


def minifyCSS(baseDir=baseDirStatic, source=cssSources):
    cssDestPath = "{}css/all.css".format(baseDir)
    cssMinPath = "{}css/all.min.css".format(baseDir)
    return saveFile(_minifyCSS, source, cssDestPath, cssMinPath, baseDir)



# -*- coding: utf-8 -*-
from __future__ import print_function, unicode_literals, with_statement, nested_scopes
import subprocess


def run_command(command_list, title=None):
    if title:
        print("\n\n>> {}".format(title))
        print("{:*^{num}}".format('', num=len(title) + 3))
    # try:
    for task in command_list:
        if task['run_stdout']:
            new_command = ""
            ret = subprocess.call(
                task['command'].split(" "),
                shell=True,
                stdout=new_command
                )

            if ret != 0:
                print('Ocorreu um erro. Processo abortado')
                return False

            ret = subprocess.call(
                new_command.split(" "),
                shell=True
                )
        else:
            ret = subprocess.call(
                task['command'].split(" "),
                shell=True
                )

        if ret != 0:
            print('Ocorreu um erro. Processo abortado')
            return False

    return True



from setuptools import setup, find_packages
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

install_requires = [
    'coverage',
    'datadog',
    'decorator',
    'docopt',
    'gitdb',
    'GitPython',
    'nose',
    'PyGithub',
    'rcssmin',
    'requests',
    'rjsmin',
    'slackweb',
    'awscli',
    'awsebcli'
]


setup(
    name='LI-AWS-Deploy',
    version='1.1.21',
    description='Deploy tool for Loja Integrada Web Applications',
    long_description=long_description,
    author='Chris Maillefaud',
    # Choose your license
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'Programming Language :: Python :: 3.5'
    ],
    keywords='aws deploy',
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),
    install_requires=install_requires,
    entry_points={
        'console_scripts': [
            'lideploy=deploy.run:start',
        ],
    },
)



# -*- coding: utf-8 -*-
from __future__ import print_function, unicode_literals, with_statement, nested_scopes
import datadog
import slackweb


class Message():
    def __init__(
            self,
            config,
            branch,
            commit,
            repo,
            action,
            test=False,
            *args,
            **kwargs):
        self.config = config
        self.branch = branch
        self.commit = commit
        self.repo = repo
        self.test = test
        self.action = action
        print("\n>> Enviando mensagens")
        print("*********************")

    def send_datadog(self, alert_type="info"):

        options = {
            'api_key': self.config['datadog_api_key'],
            'app_key': self.config['datadog_app_key']
        }

        title = "DEPLOY {}: {}/{}".format(
            self.action, self.repo, self.branch.name)
        text = self.commit
        tags = ["deploy"]

        if not self.test:
            datadog.initialize(**options)
            datadog.api.Event.create(
                title=title,
                text=text,
                tags=tags,
                alert_type=alert_type if not self.test else "info"
            )
            print("Datadog OK")
        else:
            return "{}\n{}".format(title, text)

    def send_slack(self):

        text = "DEPLOY {}: {}/{}\n{}".format(
            self.action,
            self.repo,
            self.branch.name,
            self.commit
        )

        if not self.test:
            slack = slackweb.Slack(
                url=self.config['slack_url']
            )

            slack.notify(
                text=text,
                channel="#{}".format(
                    self.config['slack_channel']) if not self.test else "#teste_automacao",
                username=self.config['slack_user'],
                icon_emoji=":{}:".format(
                    self.config['slack_icon']))
            print("Slack OK")
        else:
            return text
